CcaMode

Enum CcaMode 

pub enum CcaMode {
    Carrier = 0,
    Ed = 1,
    CarrierOrEd = 2,
    CarrierAndEd = 3,
}
Available on crate features ieee802154 and unstable only.
CCA mode

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Variants



Carrier = 0

Carrier only



Ed = 1

Energy Detect only



CarrierOrEd = 2

Carrier or Energy Detect



CarrierAndEd = 3

Carrier and Energy Detect