rssi_to_lqi

Function rssi_to_lqi 

pub fn rssi_to_lqi(rssi: i8) -> u8
Available on crate features ieee802154 and unstable only.
Convert from RSSI (Received Signal Strength Indicator) to LQI (Link Quality Indication)

RSSI is a measure of incoherent (raw) RF power in a channel. LQI is a cumulative value used in multi-hop networks to assess the cost of a link.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.