Frame

Struct Frame 

pub struct Frame {
    pub header: Header,
    pub content: FrameContent,
    pub payload: Vec<u8>,
    pub footer: [u8; 2],
}
Available on crate features ieee802154 and unstable only.
IEEE 802.15.4 MAC frame

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Fields

header: Header

Header

content: FrameContent

Content

payload: Vec<u8>

Payload

footer: [u8; 2]

This is a 2-byte CRC checksum